<?php
/**
 * Blackbird MenuManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @category            Blackbird
 * @package		Blackbird_MenuManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author		Blackbird Team
 */
namespace Blackbird\MenuManager\Block\NodeType;

use Magento\Backend\Block\Template\Context;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Exception\NoSuchEntityException;

class Category extends AbstractNodeTypeFront
{
    protected $nodes;

    /**
     * @var \Magento\Catalog\Model\ResourceModel\Category\CollectionFactory
     */
    protected $_categoryCollectionFactory;

    /**
     * Category constructor.
     *
     * @param Context $context
     * @param ResourceConnection $connection
     * @param \Magento\Catalog\Model\ResourceModel\Category\CollectionFactory $categoryCollectionFactory
     * @param array $data
     */
    public function __construct(
        Context $context,
        ResourceConnection $connection,
        \Magento\Catalog\Model\ResourceModel\Category\CollectionFactory $categoryCollectionFactory,
        $data = [])
    {
        $this->_categoryCollectionFactory = $categoryCollectionFactory;
        parent::__construct($context, $data);
    }


    /**
     * @param array $nodes
     * @throws NoSuchEntityException
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    public function fetchData(array $nodes)
    {
        $localNodes = [];
        $categoryIds = [];
        foreach ($nodes as $node) {
            $localNodes[$node->getId()] = $node;
            $categoryIds[$node->getId()] = $node->getEntityId();
        }

        /**
         * Load only one time a collection of categories
         */
        $categoryCollection = $this->_categoryCollectionFactory->create()
            ->addFieldToFilter('entity_id', ['in' => $categoryIds])
            ->addFieldToSelect('url_key');

        foreach ($categoryIds as $nodeId => $categoryId) {
            $category = $categoryCollection->getItemById($categoryId);
            if ($category) {
                $url = $category->getUrl();
                if($url == '') {
                    $url = $this->_storeManager->getStore()->getBaseUrl();
                }

                $localNodes[$nodeId]->setUrlPath($url);
            }
        }

        $this->nodes = $localNodes;
    }

    /**
     * @param $nodeId
     * @param $level
     * @param $classes
     * @param $childrenHtml
     * @param $childrenArray
     * @return string
     */
    public function getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId)
    {
        $node = $this->nodes[$nodeId];

        $url = $node->getData('url_path');
        $this->setUrl($url); // Really set the url for the front node

        $classes = $this->getIsActiveClass($url, $node, $classes, $childrenArray);

        return parent::getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray, $storeId);
    }
}